@@ -1,5 +1,12 @@
 #! /bin/bash
 
+# Determine sudo
+if hash "sudo" &>/dev/null; then
+    sudo="sudo"
+else
+    sudo=""
+fi
+
 os=$(uname)
 if [[ ! $os == "Linux" ]] && [[ ! $os == "Darwin" ]]; then
     echo "This script does not support this OS."
